bug-coreutils
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

finish renaming sha -> sha1


From: Paul Eggert
Subject: finish renaming sha -> sha1
Date: Mon, 09 Aug 2004 11:19:18 -0700
User-agent: Gnus/5.1006 (Gnus v5.10.6) Emacs/21.3 (gnu/linux)

I installed this minor cleanup to finish the renaming of "sha" to
"sha1" internally.  This is synced with gnulib.

2004-08-09  Paul Eggert  <address@hidden>

        * lib/sha1.h (sha1_ctx): Renamed from sha_ctx.
        (sha1_init_ctx): Renamed from sha_init_ctx.
        (sha1_process_block): Renamed from sha_process_block.
        (sha1_process_bytes): Renamed from sha_process_bytes.
        (sha1_finish_ctx): Renamed from sha_finish_ctx.
        (sha1_read_ctx): Renamed from sha_read_ctx.
        (sha1_stream): Renamed from sha_stream.
        (sha1_buffer): Renamed from sha_buffer.
        * lib/sha1.c: Likewise.
        * m4/sha1.m4: Renamed from sha.m4.
        (gl_SHA1): Renamed from gl_SHA.  All uses changed.
        * src/md5sum.c: Adjust to sha->sha1 renaming.

Index: lib/sha1.h
===================================================================
RCS file: /home/eggert/coreutils/cu/lib/sha1.h,v
retrieving revision 1.2
diff -p -u -r1.2 sha1.h
--- lib/sha1.h  2 Dec 2003 09:08:16 -0000       1.2
+++ lib/sha1.h  9 Aug 2004 17:29:21 -0000
@@ -23,7 +23,7 @@
 # include "md5.h"
 
 /* Structure to save state of computation between the single steps.  */
-struct sha_ctx
+struct sha1_ctx
 {
   md5_uint32 A;
   md5_uint32 B;
@@ -38,21 +38,21 @@ struct sha_ctx
 
 
 /* Initialize structure containing state of computation. */
-extern void sha_init_ctx (struct sha_ctx *ctx);
+extern void sha1_init_ctx (struct sha1_ctx *ctx);
 
 /* Starting with the result of former calls of this function (or the
    initialization function update the context for the next LEN bytes
    starting at BUFFER.
    It is necessary that LEN is a multiple of 64!!! */
-extern void sha_process_block (const void *buffer, size_t len,
-                              struct sha_ctx *ctx);
+extern void sha1_process_block (const void *buffer, size_t len,
+                               struct sha1_ctx *ctx);
 
 /* Starting with the result of former calls of this function (or the
    initialization function update the context for the next LEN bytes
    starting at BUFFER.
    It is NOT required that LEN is a multiple of 64.  */
-extern void sha_process_bytes (const void *buffer, size_t len,
-                              struct sha_ctx *ctx);
+extern void sha1_process_bytes (const void *buffer, size_t len,
+                               struct sha1_ctx *ctx);
 
 /* Process the remaining bytes in the buffer and put result from CTX
    in first 20 bytes following RESBUF.  The result is always in little
@@ -61,7 +61,7 @@ extern void sha_process_bytes (const voi
 
    IMPORTANT: On some systems it is required that RESBUF be correctly
    aligned for a 32 bits value.  */
-extern void *sha_finish_ctx (struct sha_ctx *ctx, void *resbuf);
+extern void *sha1_finish_ctx (struct sha1_ctx *ctx, void *resbuf);
 
 
 /* Put result from CTX in first 20 bytes following RESBUF.  The result is
@@ -70,18 +70,18 @@ extern void *sha_finish_ctx (struct sha_
 
    IMPORTANT: On some systems it is required that RESBUF is correctly
    aligned for a 32 bits value.  */
-extern void *sha_read_ctx (const struct sha_ctx *ctx, void *resbuf);
+extern void *sha1_read_ctx (const struct sha1_ctx *ctx, void *resbuf);
 
 
 /* Compute SHA1 message digest for bytes read from STREAM.  The
    resulting message digest number will be written into the 20 bytes
    beginning at RESBLOCK.  */
-extern int sha_stream (FILE *stream, void *resblock);
+extern int sha1_stream (FILE *stream, void *resblock);
 
 /* Compute SHA1 message digest for LEN bytes beginning at BUFFER.  The
    result is always in little endian byte order, so that a byte-wise
    output yields to the wanted ASCII representation of the message
    digest.  */
-extern void *sha_buffer (const char *buffer, size_t len, void *resblock);
+extern void *sha1_buffer (const char *buffer, size_t len, void *resblock);
 
 #endif
Index: m4/prereq.m4
===================================================================
RCS file: /home/eggert/coreutils/cu/m4/prereq.m4,v
retrieving revision 1.94
diff -p -u -r1.94 prereq.m4
--- m4/prereq.m4        5 Aug 2004 23:01:06 -0000       1.94
+++ m4/prereq.m4        9 Aug 2004 16:51:59 -0000
@@ -1,4 +1,4 @@
-#serial 44
+#serial 45
 
 dnl We use gl_ for non Autoconf macros.
 m4_pattern_forbid([^gl_[ABCDEFGHIJKLMNOPQRSTUVXYZ]])dnl
@@ -101,7 +101,7 @@ AC_DEFUN([gl_PREREQ],
   AC_REQUIRE([gl_SAVEDIR])
   AC_REQUIRE([gl_SAVE_CWD])
   AC_REQUIRE([gl_SETTIME])
-  AC_REQUIRE([gl_SHA])
+  AC_REQUIRE([gl_SHA1])
   AC_REQUIRE([gl_STDIO_SAFER])
   AC_REQUIRE([gl_STRCASE])
   AC_REQUIRE([gl_TIMESPEC])
Index: src/md5sum.c
===================================================================
RCS file: /home/eggert/coreutils/cu/src/md5sum.c,v
retrieving revision 1.125
diff -p -u -r1.125 md5sum.c
--- src/md5sum.c        30 Jul 2004 00:54:44 -0000      1.125
+++ src/md5sum.c        9 Aug 2004 18:14:25 -0000
@@ -62,7 +62,7 @@
 
 
 #define DIGEST_TYPE_STRING(Alg) ((Alg) == ALG_MD5 ? "MD5" : "SHA1")
-#define DIGEST_STREAM(Alg) ((Alg) == ALG_MD5 ? md5_stream : sha_stream)
+#define DIGEST_STREAM(Alg) ((Alg) == ALG_MD5 ? md5_stream : sha1_stream)
 
 #define DIGEST_BITS(Alg) ((Alg) == ALG_MD5 ? 128 : 160)
 #define DIGEST_HEX_BYTES(Alg) (DIGEST_BITS (Alg) / 4)
@@ -319,7 +319,7 @@ hex_digits (unsigned char const *s)
 }
 
 /* An interface to the function, DIGEST_STREAM,
-   (either md5_stream or sha_stream).
+   (either md5_stream or sha1_stream).
    Operate on FILENAME (it may be "-") and put the result in *BIN_RESULT.
    Return true if successful.  */
 
@@ -618,8 +618,8 @@ main (int argc, char **argv)
 
   if (file_type_specified & do_check)
     {
-      error (0, 0, _("the --binary and --text options are meaningless when \
-verifying checksums"));
+      error (0, 0, _("the --binary and --text options are meaningless when "
+                    "verifying checksums"));
       usage (EXIT_FAILURE);
     }
 
@@ -661,7 +661,7 @@ verifying checksums"));
          if (algorithm == ALG_MD5)
            md5_buffer (string[i], strlen (string[i]), bin_buffer);
          else
-           sha_buffer (string[i], strlen (string[i]), bin_buffer);
+           sha1_buffer (string[i], strlen (string[i]), bin_buffer);
 
          for (cnt = 0; cnt < (digest_hex_bytes / 2); ++cnt)
            printf ("%02x", bin_buffer[cnt]);





reply via email to

[Prev in Thread] Current Thread [Next in Thread]
Index: lib/sha1.c
===================================================================
RCS file: /home/eggert/coreutils/cu/lib/sha1.c,v
retrieving revision 1.3
diff -p -u -r1.3 sha1.c
--- lib/sha1.c  2 Aug 2004 05:22:22 -0000       1.3
+++ lib/sha1.c  9 Aug 2004 17:30:04 -0000
@@ -1,4 +1,4 @@
-/* sha.c - Functions to compute SHA1 message digest of files or
+/* sha1.c - Functions to compute SHA1 message digest of files or
    memory blocks according to the NIST specification FIPS-180-1.
 
    Copyright (C) 2000, 2001, 2003, 2004 Free Software Foundation, Inc.
@@ -35,7 +35,7 @@
 
 /*
   Not-swap is a macro that does an endian swap on architectures that are
-  big-endian, as SHA needs some data in a little-endian format
+  big-endian, as SHA1 needs some data in a little-endian format
 */
 
 #ifdef WORDS_BIGENDIAN
@@ -63,10 +63,10 @@ static const unsigned char fillbuf[64] =
 /*
   Takes a pointer to a 160 bit block of data (five 32 bit ints) and
   intializes it to the start constants of the SHA1 algorithm.  This
-  must be called before using hash in the call to sha_hash
+  must be called before using hash in the call to sha1_hash.
 */
 void
-sha_init_ctx (struct sha_ctx *ctx)
+sha1_init_ctx (struct sha1_ctx *ctx)
 {
   ctx->A = 0x67452301;
   ctx->B = 0xefcdab89;
@@ -84,7 +84,7 @@ sha_init_ctx (struct sha_ctx *ctx)
    IMPORTANT: On some systems it is required that RESBUF is correctly
    aligned for a 32 bits value.  */
 void *
-sha_read_ctx (const struct sha_ctx *ctx, void *resbuf)
+sha1_read_ctx (const struct sha1_ctx *ctx, void *resbuf)
 {
   ((md5_uint32 *) resbuf)[0] = NOTSWAP (ctx->A);
   ((md5_uint32 *) resbuf)[1] = NOTSWAP (ctx->B);
@@ -101,7 +101,7 @@ sha_read_ctx (const struct sha_ctx *ctx,
    IMPORTANT: On some systems it is required that RESBUF is correctly
    aligned for a 32 bits value.  */
 void *
-sha_finish_ctx (struct sha_ctx *ctx, void *resbuf)
+sha1_finish_ctx (struct sha1_ctx *ctx, void *resbuf)
 {
   /* Take yet unprocessed bytes into account.  */
   md5_uint32 bytes = ctx->buflen;
@@ -121,23 +121,23 @@ sha_finish_ctx (struct sha_ctx *ctx, voi
                                                    (ctx->total[0] >> 29));
 
   /* Process last bytes.  */
-  sha_process_block (ctx->buffer, bytes + pad + 8, ctx);
+  sha1_process_block (ctx->buffer, bytes + pad + 8, ctx);
 
-  return sha_read_ctx (ctx, resbuf);
+  return sha1_read_ctx (ctx, resbuf);
 }
 
 /* Compute SHA1 message digest for bytes read from STREAM.  The
    resulting message digest number will be written into the 16 bytes
    beginning at RESBLOCK.  */
 int
-sha_stream (FILE *stream, void *resblock)
+sha1_stream (FILE *stream, void *resblock)
 {
-  struct sha_ctx ctx;
+  struct sha1_ctx ctx;
   char buffer[BLOCKSIZE + 72];
   size_t sum;
 
   /* Initialize the computation context.  */
-  sha_init_ctx (&ctx);
+  sha1_init_ctx (&ctx);
 
   /* Iterate over full file contents.  */
   while (1)
@@ -178,17 +178,17 @@ sha_stream (FILE *stream, void *resblock
       /* Process buffer with BLOCKSIZE bytes.  Note that
                        BLOCKSIZE % 64 == 0
        */
-      sha_process_block (buffer, BLOCKSIZE, &ctx);
+      sha1_process_block (buffer, BLOCKSIZE, &ctx);
     }
 
  process_partial_block:;
 
   /* Process any remaining bytes.  */
   if (sum > 0)
-    sha_process_bytes (buffer, sum, &ctx);
+    sha1_process_bytes (buffer, sum, &ctx);
 
   /* Construct result in desired memory.  */
-  sha_finish_ctx (&ctx, resblock);
+  sha1_finish_ctx (&ctx, resblock);
   return 0;
 }
 
@@ -197,22 +197,22 @@ sha_stream (FILE *stream, void *resblock
    output yields to the wanted ASCII representation of the message
    digest.  */
 void *
-sha_buffer (const char *buffer, size_t len, void *resblock)
+sha1_buffer (const char *buffer, size_t len, void *resblock)
 {
-  struct sha_ctx ctx;
+  struct sha1_ctx ctx;
 
   /* Initialize the computation context.  */
-  sha_init_ctx (&ctx);
+  sha1_init_ctx (&ctx);
 
   /* Process whole buffer but last len % 64 bytes.  */
-  sha_process_bytes (buffer, len, &ctx);
+  sha1_process_bytes (buffer, len, &ctx);
 
   /* Put result in desired memory area.  */
-  return sha_finish_ctx (&ctx, resblock);
+  return sha1_finish_ctx (&ctx, resblock);
 }
 
 void
-sha_process_bytes (const void *buffer, size_t len, struct sha_ctx *ctx)
+sha1_process_bytes (const void *buffer, size_t len, struct sha1_ctx *ctx)
 {
   /* When we already have some bits in our internal buffer concatenate
      both inputs first.  */
@@ -226,7 +226,7 @@ sha_process_bytes (const void *buffer, s
 
       if (ctx->buflen > 64)
        {
-         sha_process_block (ctx->buffer, ctx->buflen & ~63, ctx);
+         sha1_process_block (ctx->buffer, ctx->buflen & ~63, ctx);
 
          ctx->buflen &= 63;
          /* The regions in the following copy operation cannot overlap.  */
@@ -247,14 +247,14 @@ sha_process_bytes (const void *buffer, s
       if (UNALIGNED_P (buffer))
        while (len > 64)
          {
-           sha_process_block (memcpy (ctx->buffer, buffer, 64), 64, ctx);
+           sha1_process_block (memcpy (ctx->buffer, buffer, 64), 64, ctx);
            buffer = (const char *) buffer + 64;
            len -= 64;
          }
       else
 #endif
        {
-         sha_process_block (buffer, len & ~63, ctx);
+         sha1_process_block (buffer, len & ~63, ctx);
          buffer = (const char *) buffer + (len & ~63);
          len &= 63;
        }
@@ -269,7 +269,7 @@ sha_process_bytes (const void *buffer, s
       left_over += len;
       if (left_over >= 64)
        {
-         sha_process_block (ctx->buffer, 64, ctx);
+         sha1_process_block (ctx->buffer, 64, ctx);
          left_over -= 64;
          memcpy (ctx->buffer, &ctx->buffer[64], left_over);
        }
@@ -277,7 +277,7 @@ sha_process_bytes (const void *buffer, s
     }
 }
 
 /* --- Code below is the primary difference between md5.c and sha.c --- */
 
 /* SHA1 round constants */
 #define K1 0x5a827999L
@@ -296,7 +296,7 @@ sha_process_bytes (const void *buffer, s
    Most of this code comes from GnuPG's cipher/sha1.c.  */
 
 void
-sha_process_block (const void *buffer, size_t len, struct sha_ctx *ctx)
+sha1_process_block (const void *buffer, size_t len, struct sha1_ctx *ctx)
 {
   const md5_uint32 *words = buffer;
   size_t nwords = len / sizeof (md5_uint32);
@@ -277,7 +277,7 @@ sha_process_bytes (const void *buffer, s
 }
 
-/* --- Code below is the primary difference between md5.c and sha.c --- */
+/* --- Code below is the primary difference between md5.c and sha1.c --- */
 
 /* SHA1 round constants */